@@ -2,7 +2,7 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-__version__ = "4.2.1"
+__version__ = "4.2.2"
 
 import logging
 import os, time
@@ -10,6 +10,7 @@ import re
 import glob
 from os import system
 import shutil
+import sys
 import argparse
 import json
 from xml.etree import cElementTree as et
@@ -754,3 +755,8 @@ def main():
     if os.path.exists(license_dir):        
         logger.info("Copy LICENSES directory ")
         recursive_overwrite(license_dir, os.path.join(outputdir, ta_name,"LICENSES"))
+
+    if os.path.exists(os.path.abspath(os.path.join(args.source,PARENT_DIR,"additional_packaging.py"))):
+        sys.path.insert(0,os.path.abspath(os.path.join(args.source,PARENT_DIR)))
+        from additional_packaging import additional_packaging
+        additional_packaging(ta_name)
\ No newline at end of file
